Struct DockerApi

pub struct DockerApi { /* private fields */ }

Implementations

Source

impl DockerApi

pub fn new_with_host_resolution() -> Result<Self>

Creates a new DockerApi instance using the Docker Host resolution logic from Self::get_docker_host.

pub fn image_is_present(&mut self, image: &str) -> Result<bool>

Checks the provided image exists locally.

pub fn pull_image(&mut self, image: &str) -> Result<()>

Pulls the provided image.

pub fn export_image(&mut self, image: &str) -> Result<&[u8]>

Downloads a tarball of the provided image.

pub fn into_buffer(self) -> Vec<u8>

Consumets this Docker API instance and returns the underlying buffer.

pub fn get_docker_host() -> Result<Cow<'static, str>>

Returns the resolved Docker host for the current system.