pub struct DockerApi { /* private fields */ }Implementations
Sourceimpl DockerApi
impl DockerApi
Sourcepub fn new_with_host_resolution() -> Result<Self>
pub fn new_with_host_resolution() -> Result<Self>
Creates a new DockerApi instance using the Docker Host resolution logic from Self::get_docker_host.
Sourcepub fn image_is_present(&mut self, image: &str) -> Result<bool>
pub fn image_is_present(&mut self, image: &str) -> Result<bool>
Checks the provided image exists locally.
Sourcepub fn pull_image(&mut self, image: &str) -> Result<()>
pub fn pull_image(&mut self, image: &str) -> Result<()>
Pulls the provided image.
Sourcepub fn export_image(&mut self, image: &str) -> Result<&[u8]>
pub fn export_image(&mut self, image: &str) -> Result<&[u8]>
Downloads a tarball of the provided image.
Sourcepub fn into_buffer(self) -> Vec<u8> ⓘ
pub fn into_buffer(self) -> Vec<u8> ⓘ
Consumets this Docker API instance and returns the underlying buffer.
Sourcepub fn get_docker_host() -> Result<Cow<'static, str>>
pub fn get_docker_host() -> Result<Cow<'static, str>>
Returns the resolved Docker host for the current system.